#include "testlib.h"
#include <string>
#include <vector>
#include <algorithm>

using namespace std;

const int INF = (int)1e9 + 7;

long long gcd(long long a, long long b)
{
    a = abs(a);
    b = abs(b);
    while (b)
    {
        a %= b;
        swap(a, b);
    }
    return a;
}

struct Ratio
{
    long long num, den;
    Ratio(): num(0), den(1) {}
    explicit Ratio(long long a) : num(a), den(1) {}
    Ratio(long long a, long long b)
    {
        if (b == 0)
            throw logic_error("Division by zero");
        long long g = gcd(a, b);
        if (b < 0)
            g = -g;
        num = a / g;
        den = b / g;
    }
    Ratio operator + (const Ratio& other) const
    {
        return Ratio(num * other.den + den * other.num, den * other.den);
    }
    Ratio operator - (const Ratio& other) const
    {
        return Ratio(num * other.den - den * other.num, den * other.den);
    }
    Ratio operator * (const Ratio& other) const
    {
        return Ratio(num * other.num, den * other.den);
    }
    Ratio operator / (const Ratio& other) const
    {
        return Ratio(num * other.den, den * other.num);
    }
    bool operator == (const Ratio& other) const
    {
        return num == other.num && den == other.den;
    }
};

int str_to_int(const string& s)
{
    int res = 0;
    for (int i = 0; i < (int)s.length(); ++i)
        if ('0' <= s[i] && s[i] <= '9')
            res = res * 10 + s[i] - '0';
        else
            quitf(_pe, "digits mixed with brackets");
    return res;
}

Ratio evaluate(const string& s)
{
    cerr << "eval " << s << '\n';
    if (s.empty())
        quitf(_pe, "empty operand");
    int min_bal = INF;
    vector<int> positions;
    int cur_bal = 0;
    for (int i = 0; i < (int)s.length(); ++i)
    {
        char c = s[i];
        if (c == '(')
            ++cur_bal;
        if (c == ')')
            if ((--cur_bal) < 0)
                quitf(_pe, "negative bracket balance");
        if (c == '+' || c == '-')
        {
            if (min_bal > cur_bal * 2)
            {
                min_bal = cur_bal * 2;
                positions.clear();
            }
            if (min_bal == cur_bal * 2)
                positions.push_back(i);
        }
        if (c == '*' || c == '/')
        {
            if (min_bal > cur_bal * 2 + 1)
            {
                min_bal = cur_bal * 2 + 1;
                positions.clear();
            }
            if (min_bal == cur_bal * 2 + 1)
                positions.push_back(i);
        }
    }
    if (cur_bal != 0)
        quitf(_pe, "unbalanced brackets");
    if (min_bal >= 2 && s[0] == '(')
        return evaluate(s.substr(1, s.length() - 2));
    if (min_bal == INF)
        return Ratio(str_to_int(s));
    if (positions[0] == 0 && s[0] == '+')
        quitf(_pe, "unary addition");
    if (positions[0] == 0 && s[0] == '*')
        quitf(_pe, "unary multiplication");
    if (positions[0] == 0 && s[0] == '/')
        quitf(_pe, "unary division");
    Ratio res = positions[0] == 0 ? Ratio(0) : evaluate(s.substr(0, positions[0]));
    positions.push_back((int)s.length());
    for (int i = 0; i + 1 < (int)positions.size(); ++i)
    {
        Ratio cur = evaluate(s.substr(positions[i] + 1, positions[i + 1] - positions[i] - 1));
        switch (s[positions[i]])
        {
            case '+': res = res + cur; break;
            case '-': res = res - cur; break;
            case '*': res = res * cur; break;
            case '/': res = res / cur;
        }
    }
    return res;
}

int main(int argc, char* argv[]) {
    registerTestlibCmd(argc, argv);
    string pstr = ouf.readLine("[01234()+-/*]{1,30}", "ps");
    const string expected_digits = "12340";
    int edi = 0;
    for (auto c: pstr)
        if ('0' <= c && c <= '9')
        {
            if (edi == (int)expected_digits.length())
                quitf(_wa, "too many digits");
            if (expected_digits[edi++] != c)
                quitf(_wa, "wrong digit order");
        }
    string jstr = ans.readLine("[01234()+-/*]{1,30}", "ps");
    try
    {
        Ratio peval = evaluate(pstr);
        if (peval == Ratio(100))
            quitf(_ok, "right answer");
        else
            quitf(_wa, "wrong answer %lld/%lld", peval.num, peval.den);
    }
    catch (const logic_error& e)
    {
        quitf(_wa, "division by zero");
    }
    return 0;
}
